@@ -19,8 +19,6 @@
 
 #include "Control.h"
 
-static Control::Prefs *prefs=new Control::Prefs();
-
 Control::Control()
  : backgroundColor("white",Lum::OS::display->GetColor(Lum::OS::Display::whiteColor)),
    lineColor("black",Lum::OS::display->GetColor(Lum::OS::Display::blackColor)),
@@ -28,8 +26,6 @@ Control::Control()
    player2Color("black",Lum::OS::display->GetColor(Lum::OS::Display::blackColor)),
    markColor("yellow",Lum::OS::display->GetColor(Lum::OS::Display::fillColor))
 {
-  SetPrefs(::prefs);
-
   SetCanFocus(true);
   RequestFocus();
 }
