@@ -82,7 +82,6 @@ public:
 
     control=new Control();
     control->SetFlex(true,true);
-    control->RequestFocus();
     control->SetModel(gameArea);
 
     horiz->Add(control);
@@ -94,7 +93,6 @@ public:
 
     button=new Lum::Button;
     button->SetFlex(true,false);
-    button->RequestFocus();
     button->SetModel(restartGameAction);
     button->SetText(L"_Restart Game");
     vert->Add(button);
@@ -103,7 +101,6 @@ public:
 
     button=new Lum::Button;
     button->SetFlex(true,false);
-    button->RequestFocus();
     button->SetModel(aboutAction);
     button->SetText(L"_About");
     vert->Add(button);
